@@ -22,12 +22,15 @@ class data_treatment:
 
         return new_df
     
-    def obv(self, data):
+    def obv(self, df):
+        
+        data = df.copy()
         
         first_cond = data['close']>data['close'].shift(1)
         second_cond = data['close']<data['close'].shift(1)
 
         obv = np.where(first_cond, data['volume'], np.where(second_cond, -data['volume'], 0)).cumsum()
+        
         return obv
     
     
@@ -43,6 +46,13 @@ class data_treatment:
         
         df = data.copy()
 
+        #calculate OBV
+
+        first_cond = df['close']>df['close'].shift(1)
+        second_cond = df['close']<df['close'].shift(1)
+
+        df['obv'] = np.where(first_cond, df['volume'], np.where(second_cond, -df['volume'], 0)).cumsum()
+        
         # calculate Bollinger Bands
         # moving average
         m_avg = df['close'].rolling(window=length).mean()
@@ -88,7 +98,6 @@ class data_treatment:
         fit_y = np.array(range(0,length_KC))
         df['ttm'] = df['ttm'].rolling(window = length_KC).apply(lambda x : np.polyfit(fit_y, x, 1)[0] * (length_KC-1) + np.polyfit(fit_y, x, 1)[1], raw=True)
 
-        df['obv'] = self.obv(data)
         
         df.dropna(inplace=True)
 
